employer

# XMLRésuméLibrary: User Guide

emphasis | Element Reference | fax

## Name

employer — A name of an employer

## Synopsis

### Content Model

    (#PCDATA|emphasis|citation|url|link)*

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `employer` element specifies the name of a person, company, or other entity for whom a person works or has worked.

### Parents

`employer` may be contained in these elements: `job`

### Attributes

`id`

  A string used to uniquely identify an employer. The employer may then be referred to by this identifier.

## See Also

`institution`, `organization`.

## Examples

    <job>
      <jobtitle>Angelfish Fitness Trainer</jobtitle>
      <employer>Fish Fitness Systems, Inc.</employer>
      <period>
        <from><date><month>July</month><year>1998</year></date</from>
        <to><present/></to>
      </period>
      <description>
        <para>
          Helped to ensure optimum fish health by training fish on weights and
          and fin and tail exercises.
        </para>
      </description>
    </job>

    <job>
      <jobtitle>House Cleaner</jobtitle>
      <employer>Mrs. Shirlock</employer>
      <period>
        <from><date><month>July</month><year>1954</year></date</from>
        <to><date><month>January</month><year>1956</year></date</to>
      </period>
      <para>Dusted the blinds. That is all.</para>
    </job>

emphasis | Element Reference | fax